@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u010cas Caseyho stanice",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Chilsk\u00fd standardn\u00ed \u010das",
                "",
@@ -286,6 +290,14 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "Ton\u017esk\u00fd \u010das",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukonsk\u00fd \u010das",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Alja\u0161sk\u00fd standardn\u00ed \u010das",
                "AKST",
@@ -766,14 +778,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "\u010cas ostrova lorda Howa",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u010cas ostrova Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Mark\u00e9zsk\u00fd \u010das",
                "",
@@ -1309,7 +1313,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1468,7 +1472,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1594,7 +1598,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1675,7 +1679,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1715,7 +1719,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1925,6 +1929,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Easter", "Velikono\u010dn\u00ed ostrov" },
+            { "timezone.excity.Pacific/Kanton", "Kanton" },
             { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Midway" },
