@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -286,6 +282,14 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
                "Hor\u00e1rio de Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Hor\u00e1rio do Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Hor\u00e1rio Padr\u00e3o do Alasca",
                "",
@@ -766,14 +770,6 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
                "Hor\u00e1rio de Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Hor\u00e1rio da Ilha Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Hor\u00e1rio das Marquesas",
                "",
@@ -791,7 +787,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
                "",
             };
         final String[] Singapore = new String[] {
-               "Hor\u00e1rio Padr\u00e3o de Cingapura",
+               "Hor\u00e1rio Padr\u00e3o de Singapura",
                "",
                "",
                "",
@@ -1300,7 +1296,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1446,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1572,6 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1652,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1692,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1758,6 +1753,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Manila", "Manila" },
             { "timezone.excity.Asia/Muscat", "Mascate" },
             { "timezone.excity.Asia/Riyadh", "Riade" },
+            { "timezone.excity.Asia/Saigon", "Cidade de Ho Chi Minh" },
             { "timezone.excity.Asia/Taipei", "Taipei" },
             { "timezone.excity.Asia/Tehran", "Teer\u00e3" },
             { "timezone.excity.Asia/Urumqi", "Urumqi" },
@@ -1952,7 +1948,7 @@ public class TimeZoneNames_pt extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
             { "timezone.excity.Atlantic/Azores", "A\u00e7ores" },
             { "timezone.excity.Atlantic/Canary", "Can\u00e1rias" },
-            { "timezone.excity.Atlantic/Faeroe", "Ilhas Faroe" },
+            { "timezone.excity.Atlantic/Faeroe", "Ilhas Faro\u00e9" },
             { "timezone.excity.Australia/Eucla", "Eucla" },
             { "timezone.excity.Australia/Perth", "Perth" },
             { "timezone.excity.Europe/Belgrade", "Belgrado" },
